"use strict";
/**
 *  @module Errors
 */
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var RequestErrorCode;
(function (RequestErrorCode) {
    RequestErrorCode["RequestError"] = "REQUEST_ERROR";
})(RequestErrorCode = exports.RequestErrorCode || (exports.RequestErrorCode = {}));
var ResponseErrorCode;
(function (ResponseErrorCode) {
    /* generic */
    ResponseErrorCode["BadRequest"] = "BAD_REQUEST";
    ResponseErrorCode["Forbidden"] = "FORBIDDEN";
    ResponseErrorCode["NotFound"] = "NOT_FOUND";
    ResponseErrorCode["NotAllowed"] = "NOT_ALLOWED";
    ResponseErrorCode["Conflicted"] = "CONFLICTED";
    ResponseErrorCode["TooManyRequests"] = "TOO_MANY_REQUESTS";
    ResponseErrorCode["InternalServerError"] = "INTERNAL_SERVER_ERROR";
    ResponseErrorCode["ServiceUnavailable"] = "SERVICE_UNAVAILABLE";
    ResponseErrorCode["NotAuthorized"] = "NOT_AUTHORIZED";
    /* global */
    ResponseErrorCode["UnknownError"] = "UNKNOWN_ERROR";
    ResponseErrorCode["Timeout"] = "TIMEOUT";
    ResponseErrorCode["DBError"] = "DB_ERROR";
    ResponseErrorCode["InvalidRequest"] = "INVALID_REQUEST";
    ResponseErrorCode["UnableToGetIdempotentResult"] = "UNABLE_TO_GET_IDEMPOTENT_REQUEST";
    ResponseErrorCode["ServiceUnavailableTryAgain"] = "SERVICE_UNAVAILABLE_TRY_AGAIN";
    /* auth */
    ResponseErrorCode["InvalidDomain"] = "INVALID_DOMAIN";
    ResponseErrorCode["InvalidCredentials"] = "INVALID_CREDENTIALS";
    ResponseErrorCode["AuthHeaderMissing"] = "AUTH_HEADER_MISSING";
    ResponseErrorCode["InvalidPermissions"] = "INVALID_PERMISSIONS";
    ResponseErrorCode["ImproperAuth"] = "IMPROPER_AUTH";
    ResponseErrorCode["CouldNotRefreshAuth"] = "COULD_NOT_REFRESH_AUTH";
    ResponseErrorCode["UserBanned"] = "USER_BANNED";
    ResponseErrorCode["InvalidLoginToken"] = "INVALID_LOGIN_TOKEN";
    ResponseErrorCode["InvalidAppToken"] = "INVALID_APP_TOKEN";
    ResponseErrorCode["ExpiredLoginToken"] = "EXPIRED_LOGIN_TOKEN";
    ResponseErrorCode["OutdatedAppToken"] = "OUTDATED_APP_TOKEN";
    ResponseErrorCode["ChargeTooQuick"] = "CHARGE_TOO_QUICK";
    /* file upload */
    ResponseErrorCode["FileUploadError"] = "FILE_UPLOAD_ERROR";
    ResponseErrorCode["FileMaxSizeExceeded"] = "FILE_MAX_SIE_EXCEEDED";
    ResponseErrorCode["FileInvalidType"] = "FILE_INVALID_TYPE";
    ResponseErrorCode["FileNotFound"] = "FILE_NOT_FOUND";
    /* crud actions */
    ResponseErrorCode["TokenGenerationException"] = "TOKEN_GENERATION_EXCEPTION";
    ResponseErrorCode["TokenForWrongStore"] = "TOKEN_FOR_WRONG_STORE";
    ResponseErrorCode["NonSubscriptionPayment"] = "NON_SUBSCRIPTION_PAYMENT";
    ResponseErrorCode["BankAccountExists"] = "BANK_ACCOUNT_EXISTS";
    ResponseErrorCode["EmailExists"] = "EMAIL_EXISTS";
    ResponseErrorCode["StoreExists"] = "STORE_EXISTS";
    ResponseErrorCode["GatewayCredentialsExists"] = "GATEWAY_CREDENTIALS_EXISTS";
    ResponseErrorCode["WebhookURLExists"] = "WEBHOOK_URL_EXISTS";
    ResponseErrorCode["NonUniqueRuleForMerchant"] = "NON_UNIQUE_RULE_FOR_MERCHANT";
    ResponseErrorCode["NonUniqueRuleSetForMerchant"] = "NON_UNIQUE_RULE_SET_FOR_MERCHANT";
    ResponseErrorCode["NonUniqueRule"] = "NON_UNIQUE_RULE";
    ResponseErrorCode["RulePriorityMustBePositive"] = "RULE_PRIORITY_MUST_BE_POSITIVE";
    ResponseErrorCode["NonExistingRule"] = "NON_EXISTING_RULE";
    ResponseErrorCode["MustContainUniqueElementsOnly"] = "MUST_CONTAIN_UNIQUE_ELEMENTS_ONLY";
    ResponseErrorCode["GroupExists"] = "GROUP_EXISTS";
    ResponseErrorCode["PrimaryBankAccountNotFound"] = "PRIMARY_BANK_ACCOUNT_NOT_FOUND";
    ResponseErrorCode["MustHaveAPrimaryBankAccount"] = "MUST_HAVE_A_PRIMARY_BANK_ACCOUNT";
    ResponseErrorCode["VerificationDataExists"] = "VERIFICATION_DATA_EXISTS";
    ResponseErrorCode["TemplateExists"] = "TEMPLATE_EXISTS";
    ResponseErrorCode["StratusCredentialsExists"] = "STRATUS_CREDENTIALS_EXISTS";
    ResponseErrorCode["StratusRuleStillInUse"] = "STRATUS_RULE_STILL_IN_USE";
    ResponseErrorCode["ResourceLimitReached"] = "RESOURCE_LIMIT_REACHED";
    ResponseErrorCode["OnlyOnePaidyCredentialsAllowed"] = "ONLY_ONE_PAIDY_CREDENTIALS_ALLOWED";
    /* payments and charges */
    ResponseErrorCode["InvalidTokenType"] = "INVALID_TOKEN_TYPE";
    ResponseErrorCode["InvalidToken"] = "INVALID_TOKEN";
    ResponseErrorCode["InvalidCard"] = "INVALID_CARD";
    ResponseErrorCode["ForbiddenIP"] = "FORBIDDEN_IP";
    ResponseErrorCode["InvalidUserData"] = "INVALID_USER_DATA";
    ResponseErrorCode["NonUniqueActiveToken"] = "NON_UNIQUE_ACTIVE_TOKEN";
    ResponseErrorCode["TransactionAlreadyProcessed"] = "TRANSACTION_ALREADY_PROCESSED";
    ResponseErrorCode["TransactionTokenExpired"] = "TRANSACTION_TOKEN_EXPIRED";
    ResponseErrorCode["NoTestCardInLiveMode"] = "NO_TEST_CARD_IN_LIVE_MODE";
    ResponseErrorCode["RecurringTokenNotAllowed"] = "RECURRING_TOKEN_NOT_ALLOWED";
    ResponseErrorCode["RecurringTokenDisabled"] = "RECURRING_TOKEN_DISABLED";
    ResponseErrorCode["RecurringUsageLimitRequired"] = "RECURRING_USAGE_LIMIT_REQUIRED";
    ResponseErrorCode["RecurringUsageRequiresCVV"] = "RECURRING_USAGE_REQUIRES_CVV";
    ResponseErrorCode["UsageLimitNotApplicable"] = "USAGE_LIMIT_NOT_APPLICABLE";
    ResponseErrorCode["CardProcessingDisabled"] = "CARD_PROCESSING_DISABLED";
    ResponseErrorCode["QRProcessingDisabled"] = "QR_PROCESSING_DISABLED";
    ResponseErrorCode["ConvenienceProcessingDisabled"] = "CONVENIENCE_PROCESSING_DISABLED";
    ResponseErrorCode["NotOneTimeToken"] = "NOT_ONE_TIME_TOKEN";
    ResponseErrorCode["NotSubscriptionToken"] = "NOT_SUBSCRIPTION_TOKEN";
    ResponseErrorCode["NotRecurringToken"] = "NOT_RECURRING_TOKEN";
    ResponseErrorCode["CurrencyMustMatchCharge"] = "CURRENCY_MUST_MATCH_CHARGE";
    ResponseErrorCode["RefundNotWithinBounds"] = "REFUND_NOT_WITHIN_BOUNDS";
    ResponseErrorCode["InvalidTransfer"] = "INVALID_TRANSFER";
    ResponseErrorCode["TransferAlreadyExists"] = "TRANSFER_ALREADY_EXISTS";
    ResponseErrorCode["NoLedgers"] = "NO_LEDGERS";
    ResponseErrorCode["FailedToAssociateLedgers"] = "FAILED_TO_ASSOCIATE_LEDGERS";
    ResponseErrorCode["LiveModeNotEnabledWhenUnverified"] = "LIVE_MODE_NOT_ENABLED_WHEN_UNVERIFIED";
    ResponseErrorCode["SelfTransferNotPermitted"] = "SELF_TRANSFER_NOT_PERMITTED";
    ResponseErrorCode["CardLocked"] = "CARD_LOCKED";
    ResponseErrorCode["SubscriptionProcessing"] = "SUBSCRIPTION_PROCESSING";
    ResponseErrorCode["CannotUpdateTransactionToken"] = "CANNOT_UPDATE_TRANSACTION_TOKEN";
    ResponseErrorCode["AlreadyCaptured"] = "ALREADY_CAPTURED";
    ResponseErrorCode["CaptureAmountTooLarge"] = "CAPTURE_AMOUNT_TOO_LARGE";
    ResponseErrorCode["PartialCaptureNotSupported"] = "PARTIAL_CAPTURE_NOT_SUPPORTED";
    ResponseErrorCode["NoGatewaysAvailable"] = "NO_GATEWAY_AVAILABLE";
    ResponseErrorCode["CardBrandNotSupported"] = "CARD_BRAND_NOT_SUPPORTED";
    ResponseErrorCode["CardCountryNotSupported"] = "CARD_COUNTRY_NOT_SUPPORTED";
    ResponseErrorCode["CVVRequired"] = "CVV_REQUIRED";
    ResponseErrorCode["LastNameRequired"] = "LAST_NAME_REQUIRED";
    ResponseErrorCode["AuthNotSupported"] = "AUTH_NOT_SUPPORTED";
    ResponseErrorCode["InvalidBinRange"] = "INVALID_BIN_RANGE";
    ResponseErrorCode["VerificationRequired"] = "VERIFICATION_REQUIRED";
    /* validation responses */
    ResponseErrorCode["ChangeProhibited"] = "CHARGE_PROHIBITED";
    ResponseErrorCode["ForbiddenParameter"] = "FORBIDDEN_PARAMETER";
    ResponseErrorCode["ValidationError"] = "VALIDATION_ERROR";
    ResponseErrorCode["RequiredValue"] = "REQUIRED_VALUE";
    ResponseErrorCode["MustBeFutureTime"] = "MUST_BE_FUTURE_TIME";
    ResponseErrorCode["InvalidFormat"] = "INVALID_FORMAT";
    ResponseErrorCode["InvalidPercentFee"] = "INVALID_PERCENT_FEE";
    ResponseErrorCode["InvalidCardNumber"] = "INVALID_CARD_NUMBER";
    ResponseErrorCode["InvalidCardExpiration"] = "INVALID_CARD_EXPIRATION";
    ResponseErrorCode["InvalidCVV"] = "INVALID_CVV";
    ResponseErrorCode["InvalidFormatLength"] = "INVALID_FORMAT_LENGTH";
    ResponseErrorCode["InvalidFormatUUID"] = "INVALID_UUID";
    ResponseErrorCode["InvalidFormatBase64"] = "INVALID_FORMAT_BASE64";
    ResponseErrorCode["InvalidFormatEmail"] = "INVALID_FORMAT_EMAIL";
    ResponseErrorCode["InvalidFormatCurrency"] = "INVALID_FORMAT_CURRENCY";
    ResponseErrorCode["InvalidCurrency"] = "INVALID_CURRENCY";
    ResponseErrorCode["InvalidAmount"] = "INVALID_AMOUNT";
    ResponseErrorCode["InvalidEventForStore"] = "INVALID_EVENT_FOR_STORE";
    ResponseErrorCode["InvalidEventForPlatform"] = "INVALID_EVENT_FOR_PLATFORM";
    ResponseErrorCode["InvalidEventForMerchant"] = "INVALID_EVENT_FOR_MERCHANT";
    ResponseErrorCode["InvalidFormatDomain"] = "INVALID_FORMAT_DOMAIN";
    ResponseErrorCode["InvalidFormatUrl"] = "INVALID_FORMAT_URL";
    ResponseErrorCode["InvalidFormatObject"] = "INVALID_FORMAT_OBJECT";
    ResponseErrorCode["InvalidFormatCountry"] = "INVALID_FORMAT_COUNTRY";
    ResponseErrorCode["InvalidPhoneNumber"] = "INVALID_PHONE_NUMBER";
    ResponseErrorCode["InvalidFormatSwiftCode"] = "INVALID_FORMAT_SWIFT_CODE";
    ResponseErrorCode["InvalidFormatRoutingNumber"] = "INVALID_FORMAT_ROUTING_NUMBER";
    ResponseErrorCode["InvalidFormatRoutingCode"] = "INVALID_FORMAT_ROUTING_CODE";
    ResponseErrorCode["InvalidFormatIfcsCode"] = "INVALID_FORMAT_IFCS_CODE";
    ResponseErrorCode["InvalidFormatBankAccountNumber"] = "INVALID_FORMAT_BANK_ACCOUNT_NUMBER";
    ResponseErrorCode["InvalidPasswords"] = "INVALID_PASSWORDS";
    ResponseErrorCode["InvalidTimePeriod"] = "INVALID_TIME_PERIOD";
    ResponseErrorCode["InvalidDayOfWeek"] = "INVALID_DAY_OF_WEEK";
    ResponseErrorCode["InvalidWeekOfMonth"] = "INVALID_WEEK_OF_MONTH";
    ResponseErrorCode["InvalidDayOfMonth"] = "INVALID_DAY_OF_MONTH";
    ResponseErrorCode["InvalidColorsSize"] = "INVALID_COLOR_SIZE";
    ResponseErrorCode["NestedJsonNotAllowed"] = "NESTED_JSON_NOT_ALLOWED";
    ResponseErrorCode["InvalidFormatDate"] = "INVALID_FORMAT_DATE";
    ResponseErrorCode["InvalidChargeStatus"] = "INVALID_CHARGE_STATUS";
    ResponseErrorCode["InvalidQRScanGateway"] = "INVALID_QR_SCAN_GATEWAY";
    ResponseErrorCode["CardLimitExceededForStore"] = "CARD_LIMIT_EXCEEDED_FOR_STORE";
    ResponseErrorCode["InvalidLanguage"] = "INVALID_LANGUAGE";
    ResponseErrorCode["SubscriptionNotAllowed"] = "SUBSCRIPTION_NOT_ALLOWED";
    ResponseErrorCode["OneTimeOnlyAllowed"] = "ONE_TIME_ONLY_ALLOWED";
    ResponseErrorCode["AuthExpired"] = "AUTH_EXPIRED";
    ResponseErrorCode["InvalidTemplateKey"] = "INVALID_TEMPLATE_KEY";
    ResponseErrorCode["NonPublicTemplate"] = "NON_PUBLIC_TEMPLATE";
    ResponseErrorCode["OnlyJapanesePhoneNumberAllowed"] = "ONLY_JAPANESE_PHONE_NUMBER_ALLOWED";
    ResponseErrorCode["ExpirationDateOutOfBounds"] = "EXPIRATION_DATE_OUT_OF_BOUNDS";
    ResponseErrorCode["UnsupportedLanguage"] = "UNSUPPORTED_LANGUAGE";
    ResponseErrorCode["DefaultLanguageNotSupported"] = "DEFAULT_LANGUAGE_NOT_SUPPORTED";
    ResponseErrorCode["CaptureOnlyForCardPayment"] = "CAPTURE_ONLY_FOR_CARD_PAYMENT";
    ResponseErrorCode["CaptureOnlyForCreditCards"] = "CAPTURE_ONLY_FOR_CREDIT_CARDS";
    ResponseErrorCode["InvalidScheduledCaptureDate"] = "INVALID_SCHEDULED_CAPTURE_DATE";
    ResponseErrorCode["InvalidMerchantStatus"] = "INVALID_MERCHANT_STATUS";
    ResponseErrorCode["IncoherentDateRange"] = "INCOHERENT_DATE_RANGE";
    ResponseErrorCode["MustHaveOneElement"] = "MUST_HAVE_ONE_ELEMENT";
    ResponseErrorCode["ThresholdMustBeNull"] = "THRESHOLD_MUST_BE_NULL";
    ResponseErrorCode["IllegalNumberOfItems"] = "ILLEGAL_NUMBER_OF_ITEMS";
    ResponseErrorCode["UnableToReadCredentials"] = "UNABLE_TO_READ_CREDENTIALS";
    ResponseErrorCode["GatewayError"] = "GATEWAY_ERROR";
    ResponseErrorCode["GatewayNoLongerSupported"] = "GATEWAY_NO_LONGER_SUPPORTED";
    ResponseErrorCode["InvalidChargeAmountLimit"] = "INVALID_CHARGE_AMOUNT_LIMIT";
    ResponseErrorCode["PlatformCurrencyRequiredInCvvAmount"] = "PLATFORM_CURRENCY_REQUIRED_IN_CVV_AMOUNT";
    ResponseErrorCode["TransferScheduleWaitPeriodAndPeriodRequired"] = "TRANSFER_SCHEDULE_WAIT_PERIOD_AND_PERIOD_REQUIRED";
    ResponseErrorCode["ChargeAmountTooLow"] = "CHARGE_AMOUNT_TOO_LOW";
    ResponseErrorCode["ChargeAmountTooHigh"] = "CHARGE_AMOUNT_TOO_HIGH";
    ResponseErrorCode["MustHaveAtLeastOneElement"] = "MUST_HAVE_AT_LEAST_ONE_ELEMENT";
    ResponseErrorCode["MustContainPlatformCurrency"] = "MUST_CONTAIN_PLATFORM_CURRENCY";
    /** Used when creating a new Merchant */
    ResponseErrorCode["OnlyASCII"] = "ONLY_ASCII";
    ResponseErrorCode["UniqueCharacters"] = "UNIQUE_CHARACTERS";
    ResponseErrorCode["AtLeastOneDigit"] = "AT_LEAST_ONE_DIGIT";
    ResponseErrorCode["AtLeastOneLetter"] = "AT_LEAST_ONE_LETTER";
    ResponseErrorCode["EmptyRoles"] = "EMPTY_ROLES";
    ResponseErrorCode["EditOwnRolesNotAllowed"] = "EDIT_OWN_ROLES_NOT_ALLOWED";
    ResponseErrorCode["InvalidCardBrand"] = "INVALID_CARD_BRAND";
    ResponseErrorCode["UnsupportedCountry"] = "UNSUPPORTED_COUNTRY";
    ResponseErrorCode["UnsupportedCurrency"] = "UNSUPPORTED_CURRENCY";
    ResponseErrorCode["CannotBanSelf"] = "CANNOT_BAN_SELF";
    ResponseErrorCode["CannotSelfTerminate"] = "CANNOT_SELF_TERMINATE";
    ResponseErrorCode["NoDuplicateCurrencies"] = "NO_DUPLICATE_CURRENCIES";
    ResponseErrorCode["PlatformNotFound"] = "PLATFORM_NOT_FOUND";
    ResponseErrorCode["InvalidPlatform"] = "INVALID_PLATFORM";
    ResponseErrorCode["InvalidInvoiceFeeConfiguration"] = "INVALID_INVOICE_FEE_CONFIGURATION";
    ResponseErrorCode["InvalidPlatformRole"] = "INVALID_PLATFORM_ROLE";
    /* verification */
    ResponseErrorCode["DataNotSubmitted"] = "DATA_NOT_SUBMITTED";
    ResponseErrorCode["NoBankAccount"] = "NO_BANK_ACCOUNT";
    ResponseErrorCode["PercentFeeNotSubmitted"] = "PERCENT_FEE_NOT_SUBMITTED";
    ResponseErrorCode["InsufficientSystemManagerInfo"] = "INSUFFICIENT_SYSTEM_MANAGER_INFO";
    /* gateway credentials */
    ResponseErrorCode["CredentialsExist"] = "CREDENTIALS_EXISTS";
    ResponseErrorCode["RefundExceedsChargeAmount"] = "REFUND_EXCEEDS_CHARGE_AMOUNT";
    ResponseErrorCode["CannotRefundUnsuccessfulCharge"] = "CANNOT_REFUND_UNSUCCESSFUL_CHARGE";
    ResponseErrorCode["RefundNotAllowed"] = "REFUND_NOT_ALLOWED";
    ResponseErrorCode["CancelNotAllowed"] = "CANCEL_NOT_ALLOWED";
    /* apple pay */
    ResponseErrorCode["ApplePayNotEnabled"] = "APPLE_PAY_NOT_ENABLED";
    ResponseErrorCode["ApplePayAlreadyEnabled"] = "APPLE_PAY_ALREADY_ENABLED";
    ResponseErrorCode["ApplePayCertificateAlreadyUpdated"] = "APPLE_PAY_CERTIFICATE_ALREADY_UPDATED";
    ResponseErrorCode["ApplePayUnsupportedAlgorithm"] = "APPLE_PAY_UNSUPPORTED_ALGORITHM";
    ResponseErrorCode["ApplePayCertificateNotFound"] = "APPLE_PAY_CERTIFICATE_NOT_FOUND";
    ResponseErrorCode["ApplePayUnableToGenerateCertificateRequest"] = "APPLE_PAY_UNABLE_TO_GENERATE_CERTIFICATE_REQUEST";
    ResponseErrorCode["ApplePayInvalidConfiguration"] = "APPLE_PAY_INVALID_CONFIGURATION";
    ResponseErrorCode["ApplePayInvalidCertificate"] = "APPLE_PAY_INVALID_CERTIFICATE";
    ResponseErrorCode["ApplePayInvalidAlgorithm"] = "APPLE_PAY_INVALID_ALGORITHM";
    ResponseErrorCode["ApplePayInvalidCertificateFormat"] = "APPLE_PAY_INVALID_CERTIFICATE_FORMAT";
    ResponseErrorCode["ApplePayInvalidSignature"] = "APPLE_PAY_INVALID_SIGNATURE";
    ResponseErrorCode["ApplePayError"] = "APPLE_PAY_ERROR";
    ResponseErrorCode["UnableToGenerateCertificateRequest"] = "UNABLE_TO_GENERATE_CERTIFICATE_REQUEST";
    ResponseErrorCode["InvalidMerchantSettings"] = "INVALID_MERCHANT_SETTINGS";
    ResponseErrorCode["UnsupportedAlgorithm"] = "UNSUPPORTED_ALGORITHM";
    ResponseErrorCode["InvalidPaymentToken"] = "INVALID_PAYMENT_TOKEN";
    ResponseErrorCode["ExpiredPaymentToken"] = "EXPIRED_PAYMENT_TOKEN";
    ResponseErrorCode["InvalidCertificate"] = "INVALID_CERTIFICATE";
    ResponseErrorCode["InvalidLeafCertificate"] = "INVALID_LEAF_CERTIFICATE";
    ResponseErrorCode["InvalidIntermediateCertificate"] = "INVALID_INTERMEDIATE_CERTIFICATE";
    ResponseErrorCode["InvalidChainOfTrust"] = "INVALID_CHAIN_OF_TRUST";
    ResponseErrorCode["InvalidSignature"] = "INVALID_SIGNATURE";
    /** Platform */
    ResponseErrorCode["PlatformKeyExists"] = "PLATFORM_KEY_EXISTS";
    ResponseErrorCode["MerchantConsoleURIExists"] = "MERCHANT_CONSOLE_URI_EXISTS";
    /* idempotency */
    ResponseErrorCode["IdempotencyKeyConflict"] = "IDEMPOTENCY_KEY_CONFLICT";
    /* BannedCards */
    ResponseErrorCode["CardBanned"] = "CARD_BANNED";
    // CRUD
    ResponseErrorCode["CardAlreadyBanned"] = "CARD_ALREADY_BANNED";
    ResponseErrorCode["CardNotBanned"] = "CARD_NOT_BANNED";
    ResponseErrorCode["TestCardCannotBeBanned"] = "TEST_CARD_CANNOT_BE_BANNED";
    /* Stats */
    ResponseErrorCode["InvalidMetric"] = "INVALID_METRIC";
    ResponseErrorCode["InvalidResource"] = "INVALID_RESOURCE";
    /** Installments & Subscriptions */
    ResponseErrorCode["UseStartOn"] = "USE_START_ON";
    ResponseErrorCode["PaymentInTimePeriod"] = "PAYMENT_IN_TIME_PERIOD";
    ResponseErrorCode["SecondChargeAlreadyMade"] = "SECOND_CHARGE_ALREADY_MADE";
    ResponseErrorCode["NotSupportedByProcessor"] = "NOT_SUPPORTED_BY_PROCESSOR";
    ResponseErrorCode["SubscriptionAlreadyCanceled"] = "SUBSCRIPTION_ALREADY_CANCELED";
    ResponseErrorCode["SubscriptionNotFound"] = "SUBSCRIPTION_NOT_FOUND";
    ResponseErrorCode["MustBeLowerThanFullAmount"] = "MUST_BE_LOWER_THAN_FULL_AMOUNT";
    ResponseErrorCode["InstallmentPlanNotFound"] = "INSTALLMENT_PLAN_NOT_FOUND";
    ResponseErrorCode["InstallmentAlreadySet"] = "INSTALLMENT_ALREADY_SET";
    ResponseErrorCode["InstallmentInvalidPlan"] = "INSTALLMENT_INVALID_PLAN";
    ResponseErrorCode["InstallmentInvalidPlanType"] = "INSTALLMENT_INVALID_PLAN_TYPE";
    ResponseErrorCode["InstallmentPaymentTypeNotAllowedForPlan"] = "INSTALLMENT_PAYMENT_TYPE_NOT_ALLOWED_FOR_PLAN";
    ResponseErrorCode["InstallmentInvalidInitialAmount"] = "INSTALLMENT_INVALID_INITIAL_AMOUNT";
    ResponseErrorCode["InstallmentMaxPayoutPeriodExceeded"] = "INSTALLMENT_MAX_PAYOUT_PERIOD_EXCEEDED";
    ResponseErrorCode["InstallmentInsufficientAmountPerCharge"] = "INSTALLMENT_INSUFFICIENT_AMOUNT_PER_CHARGE";
    ResponseErrorCode["InstallmentRevolvingPlanCannotSetInitialAmount"] = "INSTALLMENT_REVOLVING_PLAN_CANNOT_SET_INITIAL_AMOUNT";
    ResponseErrorCode["InstallmentRevolvingPlanCannotSetSubsequentCyclesStart"] = "INSTALLMENT_REVOLVING_PLAN_CANNOT_SET_SUBSEQUENT_CYCLES_START";
    ResponseErrorCode["InstallmentProcessorInitialAmountsNotSupported"] = "INSTALLMENT_PROCESSOR_INITIAL_AMOUNTS_NOT_SUPPORTED";
    ResponseErrorCode["InstallmentProcessorPeriodNotSupported"] = "INSTALLMENT_PROCESSOR_PERIOD_NOT_SUPPORTED";
    ResponseErrorCode["CannotChangeToken"] = "CANNOT_CHANGE_TOKEN";
    ResponseErrorCode["InstallmentsNotEnabled"] = "INSTALLMENTS_NOT_ENABLED";
    ResponseErrorCode["CannotChangeInstallmentAmount"] = "CANNOT_CHANGE_INSTALLMENT_AMOUNT";
    ResponseErrorCode["CannotChangeToInstallment"] = "CANNOT_CHANGE_TO_INSTALLMENT";
    ResponseErrorCode["MustBeMonthBasedToSet"] = "MUST_BE_MONTH_BASED_TO_SET";
    ResponseErrorCode["MustBeWithinTwoCycles"] = "MUST_BE_WITHIN_TWO_CYCLES";
    ResponseErrorCode["Deprecated"] = "DEPRECATED";
    ResponseErrorCode["CannotBeZero"] = "CANNOT_BE_ZERO";
    ResponseErrorCode["NeedAtLeastTwoCycles"] = "NEED_AT_LEAST_TWO_CYCLES";
    ResponseErrorCode["InstallmentInvalidCyclesCount"] = "INSTALLMENT_INVALID_CYCLES_COUNT";
    ResponseErrorCode["CannotSetInitialAmountToZero"] = "CANNOT_SET_INITIAL_AMOUNT_TO_ZERO";
    ResponseErrorCode["CannotSetUntilSubscriptionStarted"] = "CANNOT_SET_UNTIL_SUBSCRIPTION_STARTED";
    ResponseErrorCode["CannotSetAfterSubscriptionStarted"] = "CANNOT_SET_AFTER_SUBSCRIPTION_STARTED";
    ResponseErrorCode["CannotChangeCanceledSubscription"] = "CANNOT_CHANGE_CANCELED_SUBSCRIPTION";
    /* Stratus merchant & store configuration */
    ResponseErrorCode["StratusMerchantAlreadyExists"] = "STRATUS_MERCHANT_ALREADY_EXISTS";
    ResponseErrorCode["StratusStoreAlreadyExists"] = "STRATUS_STORE_ALREADY_EXISTS";
    ResponseErrorCode["StratusStoreAllocationLimitReached"] = "STRATUS_STORE_ALLOCATION_LIMIT_REACHED";
    /* path bindables */
    ResponseErrorCode["InvalidElasticIndex"] = "INVALID_ELASTIC_INDEX";
    ResponseErrorCode["InvalidDateHistogramInterval"] = "INVALID_DATE_HISTORY_INTERVAL";
    ResponseErrorCode["InvalidSqsEndpointKey"] = "INVALID_SQS_ENDPOINT_KEY";
    /* invalid card errors */
    ResponseErrorCode["BinNotFound"] = "BIN_NOT_FOUND";
    ResponseErrorCode["LuhnCheckFailed"] = "LUHN_CHECK_FAILED";
    ResponseErrorCode["InvalidCardNumberLength"] = "INVALID_CARD_NUMBER_LENGTH";
    ResponseErrorCode["CardPaymentDisabled"] = "CARD_PAYMENT_DISABLED";
    ResponseErrorCode["DebitDisabled"] = "DEBIT_DISABLED";
    ResponseErrorCode["PrepaidDisabled"] = "PREPAID_DISABLED";
    ResponseErrorCode["CountryNotSupported"] = "COUNTRY_NOT_SUPPORTED";
    ResponseErrorCode["Unspecified"] = "UNSPECIFIED";
})(ResponseErrorCode = exports.ResponseErrorCode || (exports.ResponseErrorCode = {}));
var APIError = /** @class */ (function (_super) {
    tslib_1.__extends(APIError, _super);
    function APIError(status, response) {
        var _this = _super.call(this) || this;
        _this.status = status;
        _this.response = Object.keys(response || {}).length !== 0 ? response : null;
        Object.setPrototypeOf(_this, APIError.prototype);
        return _this;
    }
    return APIError;
}(Error));
exports.APIError = APIError;
//# sourceMappingURL=APIError.js.map